@@ -9,6 +9,8 @@ import (
 )
 
 var List = []list.Item{
+	ASCII85Decoding{},
+	ASCII85Encoding{},
 	Base32Decode{},
 	Base32Encoding{},
 	Base64Decode{},
@@ -21,28 +23,37 @@ var List = []list.Item{
 	CountLines{},
 	CountWords{},
 	ExtractEmails{},
+	ExtractIPs{},
 	FormatJSON{},
-	HexEncode{},
-	HexToRGB{},
 	HTMLDecode{},
 	HTMLEncode{},
+	HexDecode{},
+	HexEncode{},
+	HexToRGB{},
+	JSONEscape{},
+	JSONToMSGPACK{},
 	JSONToYAML{},
+	JSONUnescape{},
 	Kebab{},
 	Lower{},
-	Markdown{},
 	MD5{},
-	Reverse{},
+	MSGPACKToJSON{},
+	Markdown{},
 	ROT13Encode{},
+	Reverse{},
+	ReverseLines{},
 	SHA1{},
 	SHA256{},
 	SHA512{},
+	ShuffleLines{},
 	Slug{},
 	Snake{},
 	SortLines{},
 	Title{},
-	Upper{},
 	URLDecode{},
 	URLEncode{},
+	UniqueLines{},
+	Upper{},
 	YAMLToJSON{},
 	Zeropad{},
 }
